==> libksieve-16.07.90.tar.xz: libksieve-16.07.90/src/ksieveui/editor/webengine/findbar/findbarwebengineview.h <==
/* Copyright (C) 2016 Laurent Montel <montel@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef WEBENGINEVIEWER_FINDBAR_MAILWEBENGINEVIEW_H
#define WEBENGINEVIEWER_FINDBAR_MAILWEBENGINEVIEW_H

#include "findbarbase.h"
#include "ksieveui_export.h"

class QWebEngineView;

namespace KSieveUi
{
class FindBarWebEngineViewPrivate;
class KSIEVEUI_EXPORT FindBarWebEngineView : public FindBarBase
{
    Q_OBJECT
public:
    explicit FindBarWebEngineView(QWebEngineView *view, QWidget *parent = Q_NULLPTR);
    ~FindBarWebEngineView();

private:
    void clearSelections() Q_DECL_OVERRIDE;
    void searchText(bool backward, bool isAutoSearch) Q_DECL_OVERRIDE;
    void updateSensitivity(bool sensitivity) Q_DECL_OVERRIDE;

private:
    FindBarWebEngineViewPrivate *const d;
};

}

#endif

==> libksieve-17.03.90.tar.xz: libksieve-17.03.90/src/ksieveui/editor/webengine/findbar/findbarwebengineview.h <==
/* Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef WEBENGINEVIEWER_FINDBAR_MAILWEBENGINEVIEW_H
#define WEBENGINEVIEWER_FINDBAR_MAILWEBENGINEVIEW_H

#include "findbarbase.h"
#include "ksieveui_export.h"

class QWebEngineView;

namespace KSieveUi
{
class FindBarWebEngineViewPrivate;
class KSIEVEUI_EXPORT FindBarWebEngineView : public FindBarBase
{
    Q_OBJECT
public:
    explicit FindBarWebEngineView(QWebEngineView *view, QWidget *parent = nullptr);
    ~FindBarWebEngineView();

private:
    void clearSelections() Q_DECL_OVERRIDE;
    void searchText(bool backward, bool isAutoSearch) Q_DECL_OVERRIDE;
    void updateSensitivity(bool sensitivity) Q_DECL_OVERRIDE;

private:
    FindBarWebEngineViewPrivate *const d;
};

}

#endif
